# PyConvox
------------------
## Description

A Wrapper application built around convox cli application. This can be modified more to restrict/limit convox access.

------------------

## Requirements

- Python version 3 and above
- Convox cli installed and configured with the key

------------------

## Installation

```sh
#Install Pyconvox using pip package (Only supported python3 and above)
pip install pyconvox
```
------------------

## Usage
```sh
usage: pyconvox [-h] {env} ...

pyconvox

positional arguments:
  {env}       Commands
    env       Get all environment variables of the specified application

optional arguments:
  -h, --help  show this help message and exit
```

